==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QSGMaterialType_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsgmaterialtype.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGMaterialType(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGMaterialType")
    QSGMaterialType *_ptr = reinterpret_cast<QSGMaterialType *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGMaterialType_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QSGMaterialType *__qt_this = new(__qtjambi_ptr) QSGMaterialType();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSGMaterialType
void __qt_destruct_QSGMaterialType(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGMaterialType")
    reinterpret_cast<QSGMaterialType*>(ptr)->~QSGMaterialType();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGMaterialType::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGMaterialType_initialize_1native__Lio_qt_quick_QSGMaterialType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGMaterialType::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGMaterialType_0, sizeof(QSGMaterialType), typeid(QSGMaterialType), false, &deleter_QSGMaterialType, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGMaterialType(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGMaterialType>("QSGMaterialType", "io/qt/quick/QSGMaterialType");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGMaterialType, {
        ConstructorInfo(&__qt_construct_QSGMaterialType_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGMaterialType);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-6.7.0.jar: sources/QtJambiQuick/QSGMaterialType_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsgmaterialtype.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGMaterialType(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGMaterialType")
    QSGMaterialType *_ptr = reinterpret_cast<QSGMaterialType *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QSGMaterialType()
void __qt_construct_QSGMaterialType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGMaterialType()")
    Q_UNUSED(__java_arguments)
    QSGMaterialType *__qt_this = new(__qtjambi_ptr) QSGMaterialType();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGMaterialType::QSGMaterialType()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGMaterialType_initialize_1native__Lio_qt_quick_QSGMaterialType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGMaterialType::QSGMaterialType()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGMaterialType, sizeof(QSGMaterialType), typeid(QSGMaterialType), false, &deleter_QSGMaterialType, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGMaterialType
void __qt_destruct_QSGMaterialType(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGMaterialType")
    reinterpret_cast<QSGMaterialType*>(ptr)->~QSGMaterialType();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGMaterialType(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGMaterialType>("QSGMaterialType", "io/qt/quick/QSGMaterialType");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGMaterialType, {
        ConstructorInfo(&__qt_construct_QSGMaterialType, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGMaterialType);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
